@@ -113,7 +113,7 @@ class TileMerger:
         if bbox:
             xy = list(
                 chain(*list(map(sorted, list(zip(
-                    *[deg2num(l[0], l[1], self.zoom) for l in
+                    *[deg2num(coord[0], coord[1], self.zoom) for coord in
                       (bbox[:2], bbox[2:])]))))))
             return dict(list(zip(keys, xy)))
         else:
@@ -222,7 +222,7 @@ class TileMerger:
             # self.create_raster_worldfile(path)
             # self.create_prj_file(path)
             outpath = os.path.abspath(path)
-            self.log('You raster - %s' % outpath)
+            self.log('raster - %s' % outpath)
             return outpath
 
     def log(self, msg):
@@ -430,9 +430,10 @@ class PkkAreaMerger(TileMerger, object):
             self.real_width = imx
             self.real_height = imy
 
-            out = Image.new('RGB', (self.real_width, self.real_height))
+            out = Image.new('L', (self.real_width, self.real_height))
             for t in tiles:
-                out.paste(t[0], t[1])
+                out.paste(t[0].convert('L'), t[1])
+                t[0].close()
             out.save(path)
         return path
 
@@ -446,6 +447,7 @@ class PkkAreaMerger(TileMerger, object):
             tile = Image.open(path)
             self.real_width = tile.width
             self.real_height = tile.height
+            tile.close()
             bb = self.bbox
             xmax = max([x["xmax"] for x in self._image_extent_list])
             ymax = max([x["ymax"] for x in self._image_extent_list])
@@ -454,7 +456,7 @@ class PkkAreaMerger(TileMerger, object):
             outpath = os.path.abspath(path)
             create_raster_worldfile(path, self.image_extent)
             create_prj_file(path)
-            self.log('You raster - %s' % outpath)
+            self.log('raster - %s' % outpath)
             return outpath
 
 
